@@ -1,8 +1,8 @@
 ;;; carbon-font.el -- fontsets for Carbon Emacs -*- coding: iso-2022-7bit -*-
 
 ;; Copyright (C) 2004-2007 by T. Hiromatsu <matsuan@users.sourceforge.jp>
-;; Version 1_5_5
-;; 2007-01-16
+;; Version 1_5_8
+;; 2008-02-24
 
 ;;; Commentary:
 
@@ -45,7 +45,7 @@
 ;;      $B$+$iF~<j2DG=$G$9!#(B
 ;;
 ;;----------------------------------------------------------------------
-;; carbon-font.el 2005-09-13$BHG(B;;
+;; carbon-font.el 2007-07-22$BHG(B;;
 ;;
 ;;  1. Introduction
 ;;  1.1. idea
@@ -56,15 +56,18 @@
 ;;          2 times width for CJK).
 ;;
 ;;      Defined fontset names are
-;;          hiraginomaru (Sans Serif)
-;;          hiraginokaku (Sans Serif)
-;;          hiraginomin (Serif)
-;;          osaka (Sans Serif)
+;;          osaka = osaka + monaco
+;;          hiramaru = $B%R%i%.%N4]%4(B + monaco
+;;          hirakaku_w3 = $B%R%i%.%N3Q%4(B w3 + monaco
+;;          hirakaku_w6 = $B%R%i%.%N3Q%4(B w6 + monaco
+;;          hirakaku_w8 = $B%R%i%.%N3Q%4(B w8 + monaco
+;;          hiramin_w3 = $B%R%i%.%NL@D+(B w3 + courier 
+;;          hiramin_w6 = $B%R%i%.%NL@D+(B w6 + courier 
 ;;
 ;;      Defined sizes are
 ;;          point 7,8,9,10,12,14,16,18,20,24
 ;;
-;;      then totally 40 fontsets were defined.
+;;      then totally 70 fontsets were defined.
 ;;
 ;;  1.2. Emacs version
 ;;      carbon-font supports only CVS version of Emacs after June 1st, 2005.
@@ -79,45 +82,16 @@
 ;;      (if (eq window-system 'mac) (require 'carbon-font))
 ;;
 ;;  2.3. set fontset
-;;      If font is defined like as 
-;;          "fontset-hiraginokaku",
-;;      12point of $B%R%i%.%N3Q%4%7%C%/(B(hiraginokaku) is used.
+;;      Use `fixed-width-set-fontset'.
+;;          Set fontset and size to `default-frame-alist' and `frame-parameter' of
+;;          current frame as `font'. if size is nil, default size of fontset will be used.
+;;          To get available fontset, use `fontset-list'.
 ;;
-;;      If you want to use other sizes, please use full XLFD name like as 
-;;            "-*-*-medium-r-normal--8-*-*-*-*-*-fontset-hiraginomaru"
+;;      example:
+;;          (fixed-width-set-fontset "hiramaru" 14)
 ;;
-;;  2.3.1. If you are not familiar to emacs lisp, follow this section.
-;;
-;;      To define default fontset, I suggest you to use
-;;      'fixed-width-set-default-fontset as below.
-;;         12point
-;;             (fixed-width-set-default-fontset "fontset-hiraginokaku")
-;;         other sizes
-;;             (fixed-width-set-default-fontset
-;;                  "-*-*-medium-r-normal--8-*-*-*-*-*-fontset-hiraginokaku")
-;;
-;;      On initial frame, to use different font from default one, please set 
-;;          (add-to-list 'initial-frame-alist '(font . "fontset-hiraginomaru"))
-;;      or
-;;          (add-to-list
-;;           'initial-frame-alist
-;;           '(font . "-*-*-medium-r-normal--8-*-*-*-*-*-fontset-hiraginomaru"))
-;;
-;;      To change fontset only on current frame, set
-;;          (set-frame-font "fontset-hiraginomaru")
-;;      or
-;;          (set-frame-font
-;;           "-*-*-medium-r-normal--8-*-*-*-*-*-fontset-hiraginomaru")
-;;
-;;  2.3.2. If you are familiar to E-lisps
-;;
-;;      In .emacs.el, by setting ('font . fontset-name) in 
-;;          'default-frame-alist
-;;      or
-;;          'initial-frame-alist
-;;      font "fontset-name" should be used.
-;;      
-;;      To change font on current frame, please use 'set-frame-font.
+;;  2.4. disable compensation of font width
+;;          (setq fixed-width-rescale nil)
 ;;
 ;;  3. create your own fontset
 ;;      If you want to create another fontset, please use  new function
@@ -170,15 +144,18 @@
 ;;	$B$3$N%U%!%$%k$O!"(Bcarbon emacs on Mac OSX $B$G!"(B2$B%P%$%HJ8;z$H!"(Bascii$B$r(B
 ;;	1:2$B$NI}$G(B($B=j0bEyI}(B)$B$G!"I=<($9$k$?$a$N(Bfontset$BDj5A$NNc$r<($7$F$$$^$9!#(B
 ;;
-;;	$BDj5A$7$F$$$k$N$O!"2<5-$N(B4$B<o$NJ8;z%;%C%H$G$9!#(B
-;;	    hiraginomaru    Monaco + $B%R%i%.%N4]%4(B
-;;	    hiraginokaku    Monaco + $B%R%i%.%N3Q%4(B
-;;	    osaka           Monaco + osaka
-;;	    hiraginomin     Courier  + $B%R%i%.%NL@D+(B
+;;	$BDj5A$7$F$$$k$N$O!"2<5-$N(B7$B<o$NJ8;z%;%C%H$G$9!#(B
+;;          osaka = osaka + monaco
+;;          hiramaru = $B%R%i%.%N4]%4(B + monaco
+;;          hirakaku_w3 = $B%R%i%.%N3Q%4(B w3 + monaco
+;;          hirakaku_w6 = $B%R%i%.%N3Q%4(B w6 + monaco
+;;          hirakaku_w8 = $B%R%i%.%N3Q%4(B w8 + monaco
+;;          hiramin_w3 = $B%R%i%.%NL@D+(B w3 + courier 
+;;          hiramin_w6 = $B%R%i%.%NL@D+(B w6 + courier 
 ;;
 ;;	    point 7,8,9,10,12,14,16,18,20,24 $B$N%5%$%:(B
 ;;
-;;	$B$rDj5A$7$F$$$^$9!#$D$^$j!"$3$N%U%!%$%k$G$O!"(B40$B<o$N!"(Bfontset $B$rDj5A(B
+;;	$B$rDj5A$7$F$$$^$9!#$D$^$j!"$3$N%U%!%$%k$G$O!"(B70$B<o$N!"(Bfontset $B$rDj5A(B
 ;;	$B$7$F$$$k$3$H$K$J$j$^$9!#(B
 ;;      default$B$N%5%$%:$O!"(B12$B$G$9!#(B
 ;; 
@@ -195,60 +172,37 @@
 ;;          carbon-font.el (this file)
 ;;          fixed-width-fontset.el
 ;;
-;;  2.2. load package
+;;  2.2. $BFI$_9~$_(B
 ;;      (if (eq window-system 'mac) (require 'carbon-font))
 ;;      $B$H$7$F$/$@$5$$!#(B
 ;;
-;;  2.3. set fontset
-;;      $B<!$N$h$&$K;XDj$7$?>l9g!"(B
-;;          "fontset-hiraginokaku"
-;;      $B%R%i%.%N3Q%4%7%C%/$N(B12point $B$,;H$o$l$^$9!#(B
+;;  2.3. $B%U%)%s%H%;%C%H$r@_Dj(B
+;;      `fixed-width-set-fontset' $B$r;H$$$^$9!#(B
+;;          Set fontset and size to `default-frame-alist' and `frame-parameter' of
+;;          current frame as `font'. if size is nil, default size of fontset will be used.
+;;          To get available fontset, use `fontset-list'.
 ;;
-;;      $B$3$l0J30$N%5%$%:$r;H$$$?$$>l9g$O!"(B
-;;            "-*-*-medium-r-normal--8-*-*-*-*-*-fontset-hiraginomaru"
-;;      $B$NMM$K!"%U%k(BXLFD$B%M!<%`$r;XDj$7$F$/$@$5$$!#(B
-;;
-;;  2.3.1. emacs lisp $B$KFk@w$NL5$$J}$N0Y$K(B
-;;
-;;      $B%G%U%)%k%H$G;H$&%U%)%s%H%;%C%H$N;XDj$9$k>l9g$O0J2<$N$h$&$K(B
-;;      fixed-width-set-default-fontset $B$r;H$C$F$/$@$5$$!#(B
-;;         12point$B$r;H$&>l9g(B
-;;             (fixed-width-set-default-fontset "fontset-hiraginokaku")
-;;         12point$B0J30$N%5%$%:$r;H$&>l9g(B
-;;             (fixed-width-set-default-fontset
-;;                  "-*-*-medium-r-normal--8-*-*-*-*-*-fontset-hiraginokaku")
-;;
-;;      $B:G=i$N%U%l!<%`$@$1!"JL$N(Bfontset$B$r;H$$$?$$>l9g$O!"(B
-;;          (add-to-list 'initial-frame-alist '(font . "fontset-hiraginomaru"))
-;;      $B$d!"(B
-;;          (add-to-list
-;;           'initial-frame-alist
-;;           '(font . "-*-*-medium-r-normal--8-*-*-*-*-*-fontset-hiraginomaru"))
-;;      $BEy$H$7$F2<$5$$!#(B
-;;
-;;      $B:#%+!<%=%k$NM-$k%U%l!<%`$@$1!"%U%)%s%H$rJQ99$7$?$$>l9g$O!"(B
-;;          (set-frame-font "fontset-hiraginomaru")
-;;      $B$d(B
-;;          (set-frame-font
-;;           "-*-*-medium-r-normal--8-*-*-*-*-*-fontset-hiraginomaru")
-;;      $B$H$7$F$/$@$5$$!#(B
-;;
-;;  2.3.2. emacs lisp $B$rM}2r$7$F5o$i$l$kJ}$K(B
-;;
-;;      .emacs.el $B$G(B
-;;          'default-frame-alist
-;;      $B5Z$S(B
-;;          'initial-frame-alist
-;;      $B$K!"(B('font . fontset-name) $B$r@_Dj$9$k$3$H$K$h$j!"(Bfontset-name $B$,3F!9(B
-;;      $BM-8z$K$J$j$^$9!#(B
-;;      $BKt!"8=:_$N%U%l!<%`$N%U%)%s%H$rJQ99$9$k$K$O!"(Bset-frame-font $B$r$*;H$$2<$5$$!#(B
+;;      $BNc(B:
+;;          (fixed-width-set-fontset "hiramaru" 14)
 ;;
 ;;  2.4. $BEyI}Jd@5$r@Z$j$?$$>l9g(B
 ;;          (setq fixed-width-rescale nil)
 ;;      $B$H$7$F$/$@$5$$!#(B
 ;;
-;;  3. $BJL$N%U%)%s%H%;%C%H$r:n$j$?$$>l9g(B
-;;      $BJL$NAH9g$;$N(B fontset $B$r@_Dj$7$?$$>l9g!#(B($B?75!G=(B)
+;;  2.5. fixed-width-fontset.0.9.0 $B$H$NI=<(8_49@-(B
+;;      (require 'carbon-font) $B$NA0$K!"(B
+;;          (setq fixed-width-use-QuickDraw-for-ascii t)
+;;      $B$r@_Dj$7$F2<$5$$!#(B
+;;
+;;      $B$3$l$r$d$k$H!"(Bmonaco $B$b!"(BQuickDraw $B$r;H$&$h$&$K$J$j$^$9!#$=$NBe$o$j!"(B
+;;      bold $B$,>/$7DY$l$F$7$^$$$^$9!#9T4V$,5M$^$j(B 0.9.0 $B$HF1MM$NI=<($K$J$j(B
+;;      $B$^$9!#(B
+;;      default $B$O(B (setq fixed-width-use-QuickDraw-for-ascii nil) $B$G!"(B
+;;      monaco $B$O(BATSUI $B$r;H$$$^$9!#(Bbold $B$OEyI}$K$J$C$F!"$9$C$-$j8+$($^$9!#(B
+;;      $BKt!"9T4V$,>/$73+$-$^$9!#(B
+;;
+;;  3. $BJL$N%U%)%s%H%;%C%H$r:n$j$?$$>l9gJL$NAH9g$;$N(B fontset $B$r@_Dj$7$?$$>l(B
+;;      $B9g!#(B($B?75!G=(B)
 ;;
 ;;      (carbon-font-create-fontset fontset size list) $B$r;H$C$F$/$@$5$$!#(B
 ;;          fontset : fontset $B$NL>A0(B(striings)
@@ -315,8 +269,14 @@
     (latin-iso8859-2 . "mac-centraleurroman")
     (cyrillic-iso8859-5 . "mac-cyrillic")))
 
+(defvar fixed-width-use-QuickDraw-for-ascii nil)
+
 (defvar fixed-width-xlfd-template
-  "-apple-%s-medium-r-normal--%d-*-*-*-*-*-iso10646-1")
+  (if fixed-width-use-QuickDraw-for-ascii
+      "-apple-%s-medium-r-normal--%d-*-*-*-*-*-mac-roman"
+    "-apple-%s-medium-r-normal--%d-*-*-*-*-*-iso10646-1"))
+
+(defvar fixed-width-fontset-template "-*-*-medium-r-normal--%d-*-*-*-*-*-fontset-%s")
 
 (defalias 'fixed-width-create-fontset-func 'create-fontset-from-mac-roman-font)
 
@@ -328,61 +288,6 @@
 
 (defvar carbon-font-defined-sizes '(12 7 8 9 10 14 16 18 20 24))
 
-;;
-;; hiraginomaru = $B%R%i%.%N4]%4(B + monaco
-;;
-
-(defvar carbon-font-encode-family-list-hiraginomaru
-  `((ascii . "monaco")
-    (japanese-jisx0208 . "hiragino maru gothic pro")
-    (katakana-jisx0201 . "hiragino maru gothic pro")
-    (japanese-jisx0212 . "hiragino maru gothic pro")
-    (thai-tis620 . "ayuthaya")
-    (chinese-gb2312 . "stheiti*")
-    (chinese-big5-1 . ,(if (x-list-fonts "*apple ligothic*")
-                           "apple ligothic*" "lihei pro*"))
-    (korean-ksc5601 . "applegothic*")))
-
-(carbon-font-create-fontset "hiraginomaru"
-                            carbon-font-defined-sizes
-                            carbon-font-encode-family-list-hiraginomaru)
-
-;;
-;; hiraginokaku = $B%R%i%.%N3Q%4(B + monaco
-;;
-
-(defvar carbon-font-encode-family-list-hiraginokaku
-  `((ascii . "monaco")
-    (japanese-jisx0208 . "hiragino kaku gothic pro")
-    (katakana-jisx0201 . "hiragino kaku gothic pro")
-    (japanese-jisx0212 . "hiragino kaku gothic pro")
-    (thai-tis620 . "ayuthaya")
-    (chinese-gb2312 . ,(if (x-list-fonts "*-hei-*") "hei*" "stheiti*"))
-    (chinese-big5-1 . "lihei pro*")
-    (korean-ksc5601 . "applegothic*")))
-
-(carbon-font-create-fontset "hiraginokaku"
-                            carbon-font-defined-sizes
-                            carbon-font-encode-family-list-hiraginokaku)
-
-;;
-;; hiraginomin = $B%R%i%.%NL@D+(B + courier 
-;;
-
-(defvar carbon-font-encode-family-list-hiraginomin
-  `((ascii . "courier")
-    (japanese-jisx0208 . "hiragino mincho pro")
-    (katakana-jisx0201 . "hiragino mincho pro")
-    (japanese-jisx0212 . "hiragino mincho pro")
-    (chinese-gb2312 . ,(if (x-list-fonts "*stkaiti*") "stkaiti*" "stheiti*"))
-    (chinese-big5-1 . ,(if (x-list-fonts "*lisong pro*") "lisong pro*" "lihei pro*"))
-    (korean-ksc5601 . ,(if (x-list-fonts "*applemyungjo*")
-                           "applemyungjo*" "applegothic*"))))
-
-(carbon-font-create-fontset "hiraginomin"
-                            carbon-font-defined-sizes
-                            carbon-font-encode-family-list-hiraginomin)
-
 ;;
 ;; osaka = osaka + monaco
 ;;
@@ -401,7 +306,123 @@
                             carbon-font-encode-family-list-osaka)
 
 ;;
-;;  $BJQ?t(B section
+;; use Quick Draw
+;;
+
+(setcdr (assoc 'japanese-jisx0208 fixed-width-encode-reg-alist) "jisx0208.*")
+(setcdr (assoc 'katakana-jisx0201 fixed-width-encode-reg-alist) "jisx0201.*")
+
+;;
+;; hiramaru = $B%R%i%.%N4]%4(B + monaco
+;;
+
+(defvar carbon-font-encode-family-list-hiramaru
+  `((ascii . "monaco")
+    (japanese-jisx0208 . "$B%R%i%.%N4]%4(B pro w4")
+    (katakana-jisx0201 . "$B%R%i%.%N4]%4(B pro w4")
+    (japanese-jisx0212 . "hiragino maru gothic pro")
+    (thai-tis620 . "ayuthaya")
+    (chinese-gb2312 . "stheiti*")
+    (chinese-big5-1 . ,(if (x-list-fonts "*apple ligothic*")
+                           "apple ligothic*" "lihei pro*"))
+    (korean-ksc5601 . "applegothic*")))
+
+(carbon-font-create-fontset "hiramaru"
+                            carbon-font-defined-sizes
+                            carbon-font-encode-family-list-hiramaru)
+
+;;
+;; hirakaku_w3 = $B%R%i%.%N3Q%4(B w3 + monaco
+;;
+
+(defvar carbon-font-encode-family-list-hirakaku_w3
+  `((ascii . "monaco")
+    (japanese-jisx0208 . "$B%R%i%.%N3Q%4(B pro w3")
+    (katakana-jisx0201 . "$B%R%i%.%N3Q%4(B pro w3")
+    (japanese-jisx0212 . "hiragino kaku gothic pro")
+    (thai-tis620 . "ayuthaya")
+    (chinese-gb2312 . ,(if (x-list-fonts "*-hei-*") "hei*" "stheiti*"))
+    (chinese-big5-1 . "lihei pro*")
+    (korean-ksc5601 . "applegothic*")))
+
+(carbon-font-create-fontset "hirakaku_w3"
+                            carbon-font-defined-sizes
+                            carbon-font-encode-family-list-hirakaku_w3)
+
+;;
+;; hirakaku_w6 = $B%R%i%.%N3Q%4(B w6 + monaco
+;;
+
+(defvar carbon-font-encode-family-list-hirakaku_w6
+  `((ascii . "monaco")
+    (japanese-jisx0208 . "$B%R%i%.%N3Q%4(B pro w6")
+    (katakana-jisx0201 . "$B%R%i%.%N3Q%4(B pro w6")
+    (japanese-jisx0212 . "hiragino kaku gothic pro")
+    (thai-tis620 . "ayuthaya")
+    (chinese-gb2312 . ,(if (x-list-fonts "*-hei-*") "hei*" "stheiti*"))
+    (chinese-big5-1 . "lihei pro*")
+    (korean-ksc5601 . "applegothic*")))
+
+(carbon-font-create-fontset "hirakaku_w6"
+                            carbon-font-defined-sizes
+                            carbon-font-encode-family-list-hirakaku_w6)
+
+;;
+;; hirakaku_w8 = $B%R%i%.%N3Q%4(B w8 + monaco
+;;
+
+(defvar carbon-font-encode-family-list-hirakaku_w8
+  `((ascii . "monaco")
+    (japanese-jisx0208 . "$B%R%i%.%N3Q%4(B std w8")
+    (katakana-jisx0201 . "$B%R%i%.%N3Q%4(B std w8")
+    (japanese-jisx0212 . "hiragino kaku gothic pro")
+    (thai-tis620 . "ayuthaya")
+    (chinese-gb2312 . ,(if (x-list-fonts "*-hei-*") "hei*" "stheiti*"))
+    (chinese-big5-1 . "lihei pro*")
+    (korean-ksc5601 . "applegothic*")))
+
+(carbon-font-create-fontset "hirakaku_w8"
+                            carbon-font-defined-sizes
+                            carbon-font-encode-family-list-hirakaku_w8)
+
+;;
+;; hiramin_w3 = $B%R%i%.%NL@D+(B w3 + courier 
+;;
+
+(defvar carbon-font-encode-family-list-hiramin_w3
+  `((ascii . "courier")
+    (japanese-jisx0208 . "$B%R%i%.%NL@D+(B pro w3")
+    (katakana-jisx0201 . "$B%R%i%.%NL@D+(B pro w3")
+    (japanese-jisx0212 . "hiragino mincho pro")
+    (chinese-gb2312 . ,(if (x-list-fonts "*stkaiti*") "stkaiti*" "stheiti*"))
+    (chinese-big5-1 . ,(if (x-list-fonts "*lisong pro*") "lisong pro*" "lihei pro*"))
+    (korean-ksc5601 . ,(if (x-list-fonts "*applemyungjo*")
+                           "applemyungjo*" "applegothic*"))))
+
+(carbon-font-create-fontset "hiramin_w3"
+                            carbon-font-defined-sizes
+                            carbon-font-encode-family-list-hiramin_w3)
+
+;;
+;; hiramin_w6 = $B%R%i%.%NL@D+(B w6 + courier 
+;;
+
+(defvar carbon-font-encode-family-list-hiramin_w6
+  `((ascii . "courier")
+    (japanese-jisx0208 . "$B%R%i%.%NL@D+(B pro w6")
+    (katakana-jisx0201 . "$B%R%i%.%NL@D+(B pro w6")
+    (japanese-jisx0212 . "hiragino mincho pro")
+    (chinese-gb2312 . ,(if (x-list-fonts "*stkaiti*") "stkaiti*" "stheiti*"))
+    (chinese-big5-1 . ,(if (x-list-fonts "*lisong pro*") "lisong pro*" "lihei pro*"))
+    (korean-ksc5601 . ,(if (x-list-fonts "*applemyungjo*")
+                           "applemyungjo*" "applegothic*"))))
+
+(carbon-font-create-fontset "hiramin_w6"
+                            carbon-font-defined-sizes
+                            carbon-font-encode-family-list-hiramin_w6)
+
+;;
+;; $BJQ?t(B section
 ;;
 
 ;;  $B;HMQ$9$k%U%)%s%H%;%C%H$rJQ$($?8e!"<+F0$G!"%\!<%k%I$r%j%9%1!<%k$5$;$k!#(B
@@ -423,6 +444,18 @@
   '(("7" . 1.15) ("8" . 1.25) ("9" . 1.35) ("10" . 1.25) ("12" . 1.2)
     ("14" . 1.2) ("16" . 1.25) ("18" . 1.25) ("20" . 1.2) ("24" . 1.2)))
 
+(defvar fixed-width-scale-alist-hirakaku-bold
+  '(("7" . 1.1) ("8" . 1.2) ("9" . 1.3) ("10" . 1.1) ("12" . 1.1)
+    ("14" . 1.1) ("16" . 1.2) ("18" . 1.2) ("20" . 1.15) ("24" . 1.15)))
+
+(defvar fixed-width-scale-alist-hirahan-bold
+  '(("7" . 0.8) ("8" . 1.1) ("9" . 1.2) ("10" . 1.0) ("12" . 1.0)
+    ("14" . 1.0) ("16" . 1.1) ("18" . 1.1) ("20" . 1.1) ("24" . 1.1)))
+
+(defvar fixed-width-scale-alist-hiramin
+  '(("7" . 1.15) ("8" . 1.35) ("9" . 1.2) ("10" . 1.2) ("12" . 1.2)
+    ("14" . 1.2) ("16" . 1.25) ("18" . 1.25) ("20" . 1.2) ("24" . 1.2)))
+
 (defvar fixed-width-scale-alist-monaco-bold
   '(("7" . 0.8) ("8" . 0.95) ("9" . 0.9) ("10" . 0.8) ("12" . 0.9)
     ("14" . 0.9) ("16" . 0.95) ("18" . 0.9) ("20" . 0.95) ("24" . 0.92)))
@@ -434,12 +467,28 @@
     (".*osaka-medium.*" . ,fixed-width-scale-alist-osaka-normal)
     (".*osaka-bold.*" . ,fixed-width-scale-alist-osaka-bold)
     ("^-apple-hiragino.*" . ,fixed-width-scale-alist-hiragino)
+    (,(encode-coding-string ".*$B%R%i%.%N4]%4(B pro w4.*" 'emacs-mule) .
+     ,fixed-width-scale-alist-hiragino)
+    (,(encode-coding-string ".*$B%R%i%.%N3Q%4(B pro w3-medium.*" 'emacs-mule) .
+     ,fixed-width-scale-alist-osaka-normal)
+    (,(encode-coding-string ".*$B%R%i%.%N3Q%4(B pro w3-bold.*jisx0208.*" 'emacs-mule) .
+     ,fixed-width-scale-alist-hirakaku-bold)
+    (,(encode-coding-string ".*$B%R%i%.%N3Q%4(B pro w3-bold.*jisx0201.*" 'emacs-mule) .
+     ,fixed-width-scale-alist-hirahan-bold)
+    (,(encode-coding-string ".*$B%R%i%.%N3Q%4(B pro w6.*" 'emacs-mule) .
+     ,fixed-width-scale-alist-hiragino)
+    (,(encode-coding-string ".*$B%R%i%.%N3Q%4(B std w8.*" 'emacs-mule) .
+     ,fixed-width-scale-alist-hiragino)
+    (,(encode-coding-string ".*$B%R%i%.%NL@D+(B pro w3.*" 'emacs-mule) .
+     ,fixed-width-scale-alist-hiramin)
+    (,(encode-coding-string ".*$B%R%i%.%NL@D+(B pro w6.*" 'emacs-mule) .
+     ,fixed-width-scale-alist-hiramin)
     ("^-apple-stheiti-.*" . ,fixed-width-scale-alist-hiragino)
     ("^-apple-lihei pro-.*" . ,fixed-width-scale-alist-hiragino)
     ("^-apple-applegothic-.*" . ,fixed-width-scale-alist-hiragino)
-    ("^-apple-applemyungjo-.*" . ,fixed-width-scale-alist-hiragino)
-    ("^-apple-lisong pro-.*" . ,fixed-width-scale-alist-hiragino)
-    ("^-apple-stkaiti-.*" . ,fixed-width-scale-alist-hiragino)
+    ("^-apple-applemyungjo-.*" . ,fixed-width-scale-alist-hiramin)
+    ("^-apple-lisong pro-.*" . ,fixed-width-scale-alist-hiramin)
+    ("^-apple-stkaiti-.*" . ,fixed-width-scale-alist-hiramin)
     ("^-apple-hei-.*" . ,fixed-width-scale-alist-hiragino)
     ("^-apple-apple ligothic-.*" . ,fixed-width-scale-alist-hiragino))
   "ReScale factor alist for each fonts and size.")
